@@ -1,6 +1,18 @@
+#
+# Copyright (C) 2000-2005 by Yasushi Saito (yasushi.saito@gmail.com)
+# 
+# Jockey is free software; you can redistribute it and/or modify it
+# under the terms of the GNU General Public License as published by the
+# Free Software Foundation; either version 2, or (at your option) any
+# later version.
+#
+# Jockey is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+# for more details.
+#
 import line_style
 import color
-import pychart_util
 import chart_object
 import object_set
 import math
@@ -103,7 +115,7 @@ class T(chart_object.T):
         <<canvas>>
         """
         if can == None: can = canvas.default_canvas()
-        self.type_check()
+        assert self.check_integrity()
         xtip = points[-1][0]
         ytip = points[-1][1]
         
