@@ -1,3 +1,16 @@
+#
+# Copyright (C) 2000-2005 by Yasushi Saito (yasushi.saito@gmail.com)
+# 
+# Jockey is free software; you can redistribute it and/or modify it
+# under the terms of the GNU General Public License as published by the
+# Free Software Foundation; either version 2, or (at your option) any
+# later version.
+#
+# Jockey is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+# for more details.
+#
 import sys
 import basecanvas
 import pscanvas
@@ -49,6 +62,8 @@ def init(fname = None, format = None):
         can = x11canvas.T(fname)
     elif format == "svg":               
         can = svgcanvas.T(fname)
+    elif format == "pdf-uncompressed":               
+        can = pdfcanvas.T(fname, False)
     else:
         can = pdfcanvas.T(fname, theme.compress_output)
     return can
@@ -75,7 +90,7 @@ def _exit():
 # 
 def line(style, x1, y1, x2, y2):
     default_canvas().line(style, x1, y1, x2, y2)
-def curve(self, style, points):
+def curve(style, points):
     default_canvas().curve(style, points)
 def clip(x1, y1, x2, y2):
     default_canvas().clip(x1, y1, x2, y2)
@@ -91,8 +106,8 @@ def ellipsis(line_style, pattern, x, y, radius, ratio = 1.0,
                               start_angle, end_angle, shadow)
 def rectangle(edge_style, pat, x1, y1, x2, y2, shadow = None):
     default_canvas().rectangle(edge_style, pat, x1, y1, x2, y2, shadow)
-def polygon(self, edge_style, pat, points, shadow = None):
-    default_canvas().polygon(self, edge_style, pat, points, shadow = None)
+def polygon(edge_style, pat, points, shadow = None):
+    default_canvas().polygon(edge_style, pat, points, shadow = None)
 def close():
     default_canvas().close()
 def round_rectangle(style, fill, x1, y1, x2, y2, radius, shadow=None):
