@@ -1,3 +1,16 @@
+#
+# Copyright (C) 2000-2005 by Yasushi Saito (yasushi.saito@gmail.com)
+#
+# Jockey is free software; you can redistribute it and/or modify it
+# under the terms of the GNU General Public License as published by the
+# Free Software Foundation; either version 2, or (at your option) any
+# later version.
+#
+# Jockey is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+# for more details.
+#
 import sys
 import os
 import re
@@ -19,15 +32,15 @@ The summary of attributes that can be set via PYCHART_OPTIONS follows:
 output=FILENAME (default: stdout)
 
     Set the output file name.
-    
+
 format=[ps|pdf|pdf-uncompressed|png|x11|svg] (default: ps)
 
     Set the output file format.
-    
+
 font-family=NAME (default: Helvetica)
 
     Set the default font to be used by texts.
-    
+
 font-size=N (default: 9)
 
     Set the default font to be used by texts.
@@ -38,7 +51,7 @@ line-width=X (default: 0.4)
 
 scale=X (default: 1.0)
 
-    Set the scaling factor.  The default is 1.0. 
+    Set the scaling factor.  The default is 1.0.
 
 color=[yes|no] (default: no)
 
@@ -64,7 +77,13 @@ default_line_width = 0.4
 debug_level = 1
 delta_bounding_box = [-3, -3, 3, 3]
 bounding_box = {}
-         
+
+creator = None
+creation_date = None
+author = None
+title = None
+aux_comments = None
+
 def parse_yesno(str):
     if str in ("yes", "true", "1"):
         return 1
@@ -73,7 +92,7 @@ def parse_yesno(str):
 
 def parse_bounding_box(arg):
     global delta_bounding_box, bounding_box
-    
+
     l = arg.split(",")
     if len(l) != 4:
         raise ValueError, "Need to specify margin=LEFT,BOTTOM,RIGHT,TOP"
@@ -106,6 +125,7 @@ def parse_option(opt, arg):
     global default_font_family, default_font_size
     global default_line_height
     global default_line_width, debug_level
+    global creator, creation_date, author, title, aux_comments
     if opt == "format":
         if arg in ("ps", "eps"):
             output_format = "ps"
@@ -135,25 +155,35 @@ def parse_option(opt, arg):
         default_font_family = arg
     elif opt == "font-size":
         default_font_size = float(arg)
-        default_line_height = float(arg)            
+        default_line_height = float(arg)
     elif opt == "line-width":
         default_line_width = float(arg)
     elif opt == "debug-level":
         debug_level = int(arg)
+    elif opt == "author":
+        author = arg
+    elif opt == "creator":
+        creator = arg
+    elif opt == "creation_date":
+        creation_date = arg
+    elif opt == "title":
+        title =arg
+    elif opt == "aux_comments":
+        aux_comments = arg
     else:
         raise getopt.GetoptError, "Unknown option: " + opt + " " + arg
-    
+
 if os.environ.has_key("PYCHART_OPTIONS"):
     for opt in os.environ["PYCHART_OPTIONS"].split():
         opt, arg = opt.split("=")
         parse_option(opt, arg)
 
-hooks = []        
+hooks = []
 def add_reinitialization_hook(proc):
     global hooks
     hooks.append(proc)
     proc()
-    
+
 def usage():
     print "Usage: %s [options..]" % sys.argv[0]
     print """
@@ -172,7 +202,7 @@ def reinitialize():
     the theme variables to other modules that depend on their values."""
     for proc in hooks:
         proc()
-    
+
 def get_options(argv = None):
     """This procedure takes a list of command line arguments in <argv>
     and parses
@@ -199,9 +229,11 @@ ar = area.T(...)
                                    ["format=", "output=", "color=",
                                     "scale=", "font-family=", "font-size=",
                                     "line-width=", "debug-level=",
+                                    "title=", "author=", "creation_date=",
+                                    "creator=",
                                     "bbox="])
-    except getopt.GetoptError, foo:
-        print foo
+    except getopt.GetoptError, arg:
+        print arg
         usage()
         raise getopt.GetoptError
     for opt, arg in opts:
@@ -217,5 +249,3 @@ ar = area.T(...)
             parse_option(opt[2:], arg)
     reinitialize()
     return args
-
-    
